@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2015 Red Hat, Inc. <http://www.redhat.com/>
@@ -165,6 +165,7 @@ def run_cmd_nodes(task, args, **kwargs):
                 (["--no-encode"] if args.no_encode else []) + \
                 (["--only-namespace-changes"] if args.only_namespace_changes
                  else []) + \
+                (["--type", args.type]) + \
                 (["--field-separator", FS] if args.full else [])
 
             opts["node_outfile"] = node_outfile
@@ -203,6 +204,7 @@ def run_cmd_nodes(task, args, **kwargs):
                 (["--no-encode"] if args.no_encode else []) + \
                 (["--only-namespace-changes"]
                     if args.only_namespace_changes else []) + \
+                (["--type", args.type]) + \
                 (["--field-separator", FS] if args.full else [])
 
             opts["node_outfile"] = node_outfile
@@ -320,6 +322,7 @@ def _get_args():
     parser = ArgumentParser(formatter_class=RawDescriptionHelpFormatter,
                             description=PROG_DESCRIPTION)
     subparsers = parser.add_subparsers(dest="mode")
+    subparsers.required = True
 
     # create <SESSION> <VOLUME> [--debug] [--force]
     parser_create = subparsers.add_parser('create')
@@ -370,6 +373,9 @@ def _get_args():
                             help="Tag prefix for file names emitted during"
                             " a full find operation; default: \"NEW\"",
                             default="NEW")
+    parser_pre.add_argument('--type', help="type: f, f-files only"
+                            " d, d-directories only, by default = both",
+                            default='both', choices=["f", "d", "both"])
     parser_pre.add_argument("--field-separator", help="Field separator string",
                             default=" ")
 
@@ -381,7 +387,7 @@ def _get_args():
                               action=StoreAbsPath)
     parser_query.add_argument("--since-time", help="UNIX epoch time since "
                               "which listing is required", type=int)
-    parser_query.add_argument("--end-time", help="UNIX epoch time upto "
+    parser_query.add_argument("--end-time", help="UNIX epoch time up to "
                               "which listing is required", type=int)
     parser_query.add_argument("--no-encode",
                               help="Do not encode path in output file",
@@ -399,6 +405,9 @@ def _get_args():
                               help="Tag prefix for file names emitted during"
                               " a full find operation; default: \"NEW\"",
                               default="NEW")
+    parser_query.add_argument('--type', help="type: f, f-files only"
+                              " d, d-directories only, by default = both",
+                              default='both', choices=["f", "d", "both"])
     parser_query.add_argument("--field-separator",
                               help="Field separator string",
                               default=" ")
@@ -507,11 +516,11 @@ def write_output(outfile, outfilemerger, field_separator):
                                                         field_separator,
                                                         p_rep,
                                                         field_separator,
-                                                        row_2_rep))
+                                                        row_2_rep).encode())
                 else:
                     f.write(u"{0}{1}{2}\n".format(row[0],
                                                   field_separator,
-                                                  p_rep))
+                                                  p_rep).encode())
 
 
 def mode_create(session_dir, args):
@@ -551,7 +560,7 @@ def mode_create(session_dir, args):
     run_cmd_nodes("create", args, time_to_update=str(time_to_update))
 
     if not os.path.exists(status_file) or args.reset_session_time:
-        with open(status_file, "w", buffering=0) as f:
+        with open(status_file, "w") as f:
             f.write(str(time_to_update))
 
     sys.stdout.write("Session %s created with volume %s\n" %
@@ -589,6 +598,8 @@ def mode_query(session_dir, args):
     enable_volume_options(args)
 
     # Test options
+    if not args.full and args.type in ["f", "d"]:
+        fail("--type can only be used with --full")
     if not args.since_time and not args.end_time and not args.full:
         fail("Please specify either {--since-time and optionally --end-time} "
              "or --full", logger=logger)
@@ -656,6 +667,9 @@ def mode_pre(session_dir, args):
 
     mkdirp(os.path.dirname(args.outfile), exit_on_err=True, logger=logger)
 
+    if not args.full and args.type in ["f", "d"]:
+        fail("--type can only be used with --full")
+
     # If Pre status file exists and running pre command again
     if os.path.exists(status_file_pre) and not args.regenerate_outfile:
         fail("Post command is not run after last pre, "
@@ -699,7 +713,7 @@ def mode_pre(session_dir, args):
 
     run_cmd_nodes("cleanup", args, tmpfilename=gtmpfilename)
 
-    with open(status_file_pre, "w", buffering=0) as f:
+    with open(status_file_pre, "w") as f:
         f.write(str(endtime_to_update))
 
     sys.stdout.write("Generated output file %s\n" % args.outfile)
